@@ -1,5 +1,13 @@
 # Transform user input for package internal use
-transform_user_input <- function(gdp, unit_in, unit_out, source, use_USA_deflator_for_all, with_regions, replace_NAs) {
+transform_user_input <- function(gdp,
+                                 unit_in,
+                                 unit_out,
+                                 source,
+                                 use_USA_cf_for_all,
+                                 with_regions,
+                                 replace_NAs,
+                                 iso3c_column,
+                                 year_column) {
   . <- NULL
 
   # Convert to tibble, if necessary
@@ -15,34 +23,59 @@ transform_user_input <- function(gdp, unit_in, unit_out, source, use_USA_deflato
     if (hasYears && spat2) gdp <- dplyr::rename(gdp, "year" = 3)
   }
 
-  # Extract base years if they exist, and adjust string
-  if (grepl("constant", unit_in)) {
-    base_x <- regmatches(unit_in, regexpr("[[:digit:]]{4}", unit_in)) %>% as.double()
-    unit_in <- sub(base_x, "YYYY", unit_in) %>% paste0(" base x")
-  }
-  if (grepl("constant", unit_out)) {
-    base_y <- regmatches(unit_out, regexpr("[[:digit:]]{4}", unit_out)) %>% as.double()
-    unit_out <- sub(base_y, "YYYY", unit_out) %>% paste0(" base y")
+  # Extract base years if they exist, and adjust strings of units
+  handle_unit <- function(x, inOrOut) {
+    if (grepl("constant", x)) {
+      base_year <- as.double(regmatches(x, regexpr("[[:digit:]]{4}", x)))
+      x <- sub(paste0(" ", base_year), "", x)
+      x <- if (inOrOut == "in") paste0(x, "_base_x") else paste0(x, "_base_y")
+    } else {
+      base_year <- NULL
+    }
+
+    x <- sub("US\\$MER", "USA_CU", x)
+    x <- sub("\u20ac|EUR", "DEU_CU", x)
+    x <- sub("Int\\$PPP", "IntPPP", x)
+
+    iso3cOfUnit <- sub("_CU", "", regmatches(x, regexpr("..._CU", x)))
+    if (!rlang::is_empty(iso3cOfUnit)) x <- sub(paste0(iso3cOfUnit, "_"), "x", x)
+    x <- sub(" ", "_", x)
+
+    list("x" = x, "base_year" = base_year, "iso3cOfUnit" = iso3cOfUnit)
   }
+  helper_unit_in <- handle_unit(unit_in, "in")
+  base_x <- helper_unit_in$base_year
+  iso3c_x <- helper_unit_in$iso3cOfUnit
+  unit_in <- helper_unit_in$x
+  helper_unit_out <- handle_unit(unit_out, "out")
+  base_y <- helper_unit_out$base_year
+  iso3c_y <- helper_unit_out$iso3cOfUnit
+  unit_out <- helper_unit_out$x
+
   require_year_column <- any(grepl("current", c(unit_in, unit_out)))
 
   # Rename columns if necessary
   if (! "iso3c" %in% colnames(gdp)) {
-    i_iso3c <- smart_select_iso3c(gdp)
+    i_iso3c <- smart_select_iso3c(gdp, iso3c_column)
     if (length(i_iso3c) != 1) {
-      abort("Invalid 'gdp' argument. `gdp` has no 'iso3c' column, and no other \\
-               column could be identified in its stead.")
+      abort(glue::glue("Invalid 'gdp' argument. `gdp` has no '{iso3c_column}' column, and no other \\
+                        column could be identified in its stead."))
+    }
+    if (i_iso3c != iso3c_column) {
+      warn(glue::glue("No '{iso3c_column}' column in 'gdp' argument. Using '{i_iso3c}' column instead."))
     }
-    warn("No 'iso3c' column in 'gdp' argument. Using '{i_iso3c}' column instead.")
     gdp <- dplyr::rename(gdp, "iso3c" = !!rlang::sym(i_iso3c))
+
   }
   if (require_year_column && ! "year" %in% colnames(gdp)) {
-    i_year <- smart_select_year(gdp)
+    i_year <- smart_select_year(gdp, year_column)
     if (length(i_year) != 1) {
-      abort("Invalid 'gdp' argument. 'gdp' does not have a 'year' column, required when converting current values, \\
-             and no other column could be identified in its stead.")
+      abort(glue::glue("Invalid 'gdp' argument. 'gdp' does not have a '{year_column}' column, required when \\
+                          converting current values, and no other column could be identified in its stead."))
+    }
+    if (i_year != year_column) {
+      warn(glue::glue("No '{year_column}' column in 'gdp' argument. Using '{i_year}' column instead."))
     }
-    warn("No 'year' column in 'gdp' argument. Using '{i_year}' column instead.")
     gdp <- dplyr::rename(gdp, "year" = !!rlang::sym(i_year))
   }
 
@@ -50,23 +83,23 @@ transform_user_input <- function(gdp, unit_in, unit_out, source, use_USA_deflato
   source_name <- if (is.character(source)) source else "user_provided"
   source <- check_source(source)
 
-  # If a region mapping is available and a region code (that isn't a
-  # country-region) is detected, replace the region with the countries it
-  # comprises.
+  # If a region mapping is available and a region code (that isn't a country-region) is detected, replace the region
+  # with the countries it comprises.
+  if (is.character(with_regions)) {
+    with_regions <- madrat::toolGetMapping(with_regions) %>%
+      dplyr::select("iso3c" = "CountryCode", "region" = "RegionCode")
+  }
   if (!is.null(with_regions) &&
       any(gdp$iso3c %in% with_regions$region & !gdp$iso3c %in% with_regions$iso3c)) {
     gdp <- replace_regions_with_countries(gdp, unit_in, base_x, with_regions, source)
   }
 
-  # Need this to check for existence of base_y and base_x
-  this_e <- environment()
-
   # Check that base_y and base_x years exist in the source
-  if (exists("base_y", envir = this_e, inherits = FALSE) && !base_y %in% source$year) {
+  if (!is.null(base_y) && !base_y %in% source$year) {
     abort("Incompatible 'unit_out' and 'source'. No information in source {crayon::bold(source_name)} for the \\
           year {base_y}.")
   }
-  if (exists("base_x", envir = this_e, inherits = FALSE) && !base_x %in% source$year) {
+  if (!is.null(base_x) && !base_x %in% source$year) {
     abort("Incompatible 'unit_in' and 'source'. No information in source {crayon::bold(source_name)} for the \\
           year {base_x}.")
   }
@@ -75,13 +108,11 @@ transform_user_input <- function(gdp, unit_in, unit_out, source, use_USA_deflato
     abort("Incompatible 'gdp' and 'source'. No information in source {crayon::bold(source_name)} for years in 'gdp'.")
   }
 
-  # Use different source if required by the replace_NAs argument
-  if (use_USA_deflator_for_all ||
+  # Use different source if required by the use_USA_cf_for_all and replace_NAs argument
+  if (use_USA_cf_for_all) source <- adapt_source_USA(gdp, source)
+  if (!use_USA_cf_for_all &&
       (!is.null(replace_NAs) && !any(sapply(c(NA, 0, "no_conversion"), setequal, replace_NAs))) ) {
-    if (use_USA_deflator_for_all || replace_NAs[1] == "with_USA") source <- adapt_source_USA(gdp, source, replace_NAs)
-    if (!is.null(replace_NAs) && !any(sapply(c(NA, 0, "no_conversion", "with_USA"), setequal, replace_NAs))){
-      source <- adapt_source(gdp, source, with_regions, replace_NAs, require_year_column)
-    }
+    source <- adapt_source(gdp, source, with_regions, replace_NAs, require_year_column)
     source_name <- paste0(source_name, "_adapted")
   }
 
@@ -92,11 +123,13 @@ transform_user_input <- function(gdp, unit_in, unit_out, source, use_USA_deflato
   list("gdp" = gdp,
        "unit_in" = unit_in,
        "unit_out" = unit_out,
+       "iso3c_x" = iso3c_x,
+       "iso3c_y" = iso3c_y,
+       "base_x" = base_x,
+       "base_y" = base_y,
        "require_year_column" = require_year_column,
        "source" = source,
-       "source_name" = source_name) %>%
-    {if (exists("base_x", envir = this_e, inherits = FALSE)) c(., "base_x" = base_x) else .} %>%
-    {if (exists("base_y", envir = this_e, inherits = FALSE)) c(., "base_y" = base_y) else .}
+       "source_name" = source_name)
 }
 
 
@@ -104,7 +137,7 @@ transform_user_input <- function(gdp, unit_in, unit_out, source, use_USA_deflato
 
 
 # Transform user input for package internal use
-transform_internal <- function(x, gdp, with_regions, require_year_column) {
+transform_internal <- function(x, gdp, with_regions, require_year_column, iso3c_column, year_column) {
 
   if (!is.null(with_regions) && "gdpuc_region" %in% colnames(x)) {
     x_reg <- dplyr::filter(x, !is.na(.data$gdpuc_region))
@@ -129,9 +162,9 @@ transform_internal <- function(x, gdp, with_regions, require_year_column) {
     # Check if the original magpie object had 2 spatial dimensions
     spat2 <- all(grepl("\\.", magclass::getItems(gdp, dim = 1)))
     if (!spat2) {
-      x <- magclass::as.magpie(x, spatial = "iso3c", temporal = "year")
+      x <- magclass::as.magpie(x, spatial = "iso3c", temporal = "year", datacol = "value")
     } else {
-      x <- magclass::as.magpie(x, spatial = c("iso3c", "spatial2"), temporal = "year")
+      x <- magclass::as.magpie(x, spatial = c("iso3c", "spatial2"), temporal = "year", datacol = "value")
     }
     magclass::getSets(x) <- magclass::getSets(gdp)
     return(x)
@@ -139,11 +172,11 @@ transform_internal <- function(x, gdp, with_regions, require_year_column) {
 
   # Get original iso3c and year column names
   if (! "iso3c" %in% colnames(gdp)) {
-    i_iso3c <- smart_select_iso3c(gdp)
+    i_iso3c <- smart_select_iso3c(gdp, iso3c_column)
     x <- dplyr::rename(x, !!rlang::sym(i_iso3c) := "iso3c")
   }
   if (require_year_column && ! "year" %in% colnames(gdp)) {
-    i_year <- smart_select_year(gdp)
+    i_year <- smart_select_year(gdp, year_column)
     x <- dplyr::rename(x, !!rlang::sym(i_year) := "year")
   }
 
