@@ -50,15 +50,16 @@ test_that("with_regions argument", {
                                 unit_in,
                                 unit_out,
                                 source = s,
-                                use_USA_deflator_for_all = FALSE,
-                                with_regions = "blabla"))
+                                use_USA_cf_for_all = FALSE,
+                                with_regions = 1),
+               "Invalid 'with_regions' argument. Has to be either a string, or a data.frame.")
 
   with_regions <- tibble::tibble("blabla" = "FRA", "region" = "USA")
   expect_error(check_user_input(gdp,
                                 unit_in,
                                 unit_out,
                                 source = s,
-                                use_USA_deflator_for_all = FALSE,
+                                use_USA_cf_for_all = FALSE,
                                 with_regions = with_regions))
 
   with_regions <- tibble::tibble("iso3c" = "FRA", "region" = "USA")
@@ -66,7 +67,7 @@ test_that("with_regions argument", {
                                 unit_in,
                                 "current LCU",
                                 source = s,
-                                use_USA_deflator_for_all = FALSE,
+                                use_USA_cf_for_all = FALSE,
                                 with_regions = with_regions))
 
   my_bad_source <- wb_wdi %>% dplyr::select(
@@ -81,11 +82,12 @@ test_that("with_regions argument", {
                                 unit_in,
                                 unit_out,
                                 source = s,
-                                use_USA_deflator_for_all = FALSE,
+                                use_USA_cf_for_all = FALSE,
                                 with_regions = with_regions))
 })
 
-test_that("replace_NAs argument", {
+test_that("with_regions argument - madrat mapping", {
+  skip_if_not_installed("madrat")
 
   gdp <- tibble::tibble("iso3c" = "EUR", "year" = 2010, "value" = 100)
   unit_in <- "current Int$PPP"
@@ -96,26 +98,49 @@ test_that("replace_NAs argument", {
                                 unit_in,
                                 unit_out,
                                 source = s,
-                                use_USA_deflator_for_all = FALSE,
-                                replace_NAs = 2,
-                                with_regions = NULL),
-               glue::glue("Invalid 'replace_NAs' argument. Has to be either NULL, NA, 0, 1, no_conversion, linear, \\
-                          regional_average, with_USA or a combination of the above."))
-  expect_error(check_user_input(gdp,
-                                unit_in,
-                                unit_out,
-                                source = s,
-                                use_USA_deflator_for_all = FALSE,
-                                replace_NAs = c(0, 1),
-                                with_regions = NULL),
-               glue::glue("Invalid 'replace_NAs' argument. The only accepted combinations of arguments start with \\
-                          'linear', e.g. c\\('linear', 'no_conversion'\\)."))
+                                use_USA_cf_for_all = FALSE,
+                                with_regions = "badMapping"),
+               "Invalid 'with_regions' argument. Unknown regionmapping.")
+})
+
+
+test_that("replace_NAs argument", {
+
+  gdp <- tibble::tibble("iso3c" = "EUR", "year" = 2010, "value" = 100)
+  unit_in <- "current Int$PPP"
+  unit_out <- "current US$MER"
+  s <- wb_wdi
+
   expect_error(
     check_user_input(gdp,
                      unit_in,
                      unit_out,
                      source = s,
-                     use_USA_deflator_for_all = FALSE,
+                     use_USA_cf_for_all = FALSE,
+                     replace_NAs = 2,
+                     with_regions = NULL),
+    glue::glue("Invalid 'replace_NAs' argument. Has to be either NULL, NA, 0, no_conversion, linear, \\
+                          regional_average, with_USA or a combination of the above.")
+  )
+
+  expect_error(
+    check_user_input(gdp,
+                     unit_in,
+                     unit_out,
+                     source = s,
+                     use_USA_cf_for_all = FALSE,
+                     replace_NAs = c(0, "linear"),
+                     with_regions = NULL),
+    glue::glue("Invalid 'replace_NAs' argument. The only accepted combinations of arguments start with \\
+                          'linear', e.g. c\\('linear', 'no_conversion'\\).")
+  )
+
+  expect_error(
+    check_user_input(gdp,
+                     unit_in,
+                     unit_out,
+                     source = s,
+                     use_USA_cf_for_all = FALSE,
                      replace_NAs = "linear_regional_average",
                      with_regions = NULL)
   )
@@ -125,7 +150,7 @@ test_that("replace_NAs argument", {
                      unit_in,
                      unit_out,
                      source = s,
-                     use_USA_deflator_for_all = FALSE,
+                     use_USA_cf_for_all = FALSE,
                      replace_NAs = "regional_average",
                      with_regions = NULL),
     glue::glue("Using 'regional_average' requires a region mapping. The 'with_regions' argument can't be NULL.")
@@ -143,7 +168,7 @@ test_that("boolean arguments", {
                                 unit_in,
                                 unit_out,
                                 source = s,
-                                use_USA_deflator_for_all = FALSE,
+                                use_USA_cf_for_all = FALSE,
                                 with_regions = NULL,
                                 replace_NAs = NULL,
                                 verbose = "blabla"))
@@ -153,7 +178,7 @@ test_that("boolean arguments", {
     unit_in,
     unit_out,
     source = s,
-    use_USA_deflator_for_all = FALSE,
+    use_USA_cf_for_all = FALSE,
     with_regions = NULL,
     replace_NAs = NULL,
     verbose = TRUE,
@@ -164,29 +189,43 @@ test_that("boolean arguments", {
     unit_in,
     unit_out,
     source = s,
-    use_USA_deflator_for_all = "blabla",
+    use_USA_cf_for_all = "blabla",
     with_regions = NULL,
     replace_NAs = NULL,
     verbose = TRUE,
     return_cfs = TRUE))
 })
 
-
-test_that("boolean arguments", {
+test_that("character arguments", {
 
   gdp <- tibble::tibble("iso3c" = "EUR", "year" = 2010, "value" = 100)
   unit_in <- "current Int$PPP"
-  unit_out <- "constant 2010 US$MER"
+  unit_out <- "current US$MER"
   s <- wb_wdi
 
-  expect_error(check_user_input(
-    gdp,
-    unit_in,
-    unit_out,
-    source = s,
-    use_USA_deflator_for_all = TRUE,
-    with_regions = NULL,
-    replace_NAs = NULL,
-    verbose = TRUE,
-    return_cfs = TRUE))
+  expect_error(check_user_input(gdp,
+                                unit_in,
+                                unit_out,
+                                source = s,
+                                use_USA_cf_for_all = FALSE,
+                                with_regions = NULL,
+                                replace_NAs = NULL,
+                                verbose = FALSE,
+                                return_cfs = FALSE,
+                                iso3c_column = TRUE,
+                                year_column = "year"),
+               "Invalid 'iso3c_column' argument. Has to be a string.")
+
+  expect_error(check_user_input(gdp,
+                                unit_in,
+                                unit_out,
+                                source = s,
+                                use_USA_cf_for_all = FALSE,
+                                with_regions = NULL,
+                                replace_NAs = NULL,
+                                verbose = FALSE,
+                                return_cfs = FALSE,
+                                iso3c_column = "iso3c",
+                                year_column = 2),
+               "Invalid 'year_column' argument. Has to be a string.")
 })
